const colors = require('./../src/colors');
const radii = require('./../src/radii');
const shadows = require('./../src/shadows');
const spacingTokens = require('./../src/spacing');
const transitions = require('./../src/transition');
const typography = require('./../src/typography');

// - COLORS -------------------------------------------------------------------/
/**
 * Returns the hex color for the cirrus color name.
 * For the possible values see:
 * https://cirrus.lightspeedhq.com/?selectedKind=tokens&selectedStory=Colors
 * @param {string} value The cirrus color name (e.g. "blue-200")
 * @return {string} the hex value of the color
 */
export function color(value) {
  return colors.colors[value];
}

// - RADII --------------------------------------------------------------------/
/**
 * Returns the border-radius CSS value as a string in rem.
 * For the possible values see:
 * https://cirrus.lightspeedhq.com/?selectedKind=tokens&selectedStory=Border%20Radii
 * @param {number|string} value The radius scale (can also be 'circle')
 * @return {string} the scale in rem
 */
export function radius(value) {
  return radii.values[`radius-${value}`];
}

// - SHADOWS ------------------------------------------------------------------/
/**
 * Returns the outer shadow CSS value as a string.
 * For the possible values see
 * https://cirrus.lightspeedhq.com/?selectedKind=tokens&selectedStory=Shadows
 * @param {number|string} value The scale of the outer shadow (e.g. 2)
 * @return {string} The outer shadow CSS value
 */
export function shadow(value) {
  return shadows.outer[`shadow-${value}`];
}

/**
 * Returns the inner shadow CSS value as a string.
 * For the possible values see:
 * https://cirrus.lightspeedhq.com/?selectedKind=tokens&selectedStory=Shadows
 * @param {number|string} value The scale of the inner shadow (also supports: "n1")
 * @return {string} The inner shadow CSS value
 */
export function innerShadow(value) {
  if (typeof value === 'string' && value.indexOf('n') === 0) {
    return shadows.innerN[`inner-shadow-${value}`];
  }

  return shadows.inner[`inner-shadow-${value}`];
}

/**
 * Returns a shadow value as a string that can be used as a replacement for
 * a border. Useful for images and elements on top of images.
 * @return {string} The border shadow CSS value
 */
export function borderShadow() {
  return shadows.border['border-shadow'];
}

// - SPACING ------------------------------------------------------------------/
/**
 * Returns the spacing value in rem as a string
 * For the possible values see:
 * https://cirrus.lightspeedhq.com/?selectedKind=tokens&selectedStory=Spacing
 * @param {number|string} value a spacing scale value (e.g. 5)
 * @return {string} the scale in rem
 */
export function spacing(value) {
  return spacingTokens.scale[`spacing-${value}`];
}

// - TRANSITION ---------------------------------------------------------------/
/**
 * Returns the duration as a string including the ms.
 * For the possible values see:
 * https://cirrus.lightspeedhq.com/?selectedKind=tokens&selectedStory=Transitions
 * @param {string} value The speed name of the duration (e.g. "slow")
 * @return {string} the speed including ms
 */
export function duration(value) {
  return transitions.durations[`transition-duration-${value}`];
}

// - TYPOGRAPHY ---------------------------------------------------------------/
/**
 * Returns the font combinations based on the type.
 * For the possible values see:
 * https://cirrus.lightspeedhq.com/?selectedKind=tokens&selectedStory=Typography
 * @param {string} value The type of the typeface (e.g. "sans-serif")
 * @return {string} the fonts that are part of this typeface
 */
export function typeface(value) {
  return typography.typeface[value];
}

/**
 * Returns the font weight value based on the weight name.
 * For the possible values see:
 * https://cirrus.lightspeedhq.com/?selectedKind=tokens&selectedStory=Typography
 * @param {string} value the weight of the typeface (e.g. "bold")
 * @return {string} the weight value as a string
 */
export function fontWeight(value) {
  return typography.weights[value];
}

/**
 * Returns the font size based on the size name.
 * For the possible values see:
 * https://cirrus.lightspeedhq.com/?selectedKind=tokens&selectedStory=Typography
 * @param {string} [value=""] the font-size definition (e.g. "xxs") (defaults to the base size)
 * @return {string} the font-size in rem
 */
export function fontSize(value = '') {
  if (value === '') {
    return typography.fontSizes.text;
  }

  return typography.fontSizes[`text-${value}`];
}

/**
 * Returns the letter spacing in rem as a string.
 * For the possible values see:
 * https://cirrus.lightspeedhq.com/?selectedKind=tokens&selectedStory=Typography
 * @param {number|string} value The letter spacing scale (e.g. 2)
 * @return {string} the letter spacing in rem
 */
export function letterSpacing(value) {
  return typography.letterSpacings[`letter-spacing-${value}`];
}
